@@ -13,7 +13,7 @@ pub fn read_and_execute(
     keymap_t: &AppKeyMapping,
     prefix: &str,
     suffix: &str,
-) -> JoshutoResult<()> {
+) -> JoshutoResult {
     context.flush_event();
     let user_input: Option<String> = TuiTextField::default()
         .prompt(":")
