@@ -5,10 +5,12 @@ pub mod cursor_move;
 pub mod delete_files;
 pub mod file_ops;
 pub mod help;
+pub mod line_nums;
 pub mod new_directory;
+pub mod numbered_command;
 pub mod open_file;
 pub mod parent_cursor_move;
-pub mod parent_directory;
+pub mod preview_cursor_move;
 pub mod quit;
 pub mod reload;
 pub mod rename_file;
