@@ -13,6 +13,7 @@ impl Message {
     }
 }
 
+#[derive(Default)]
 pub struct MessageQueue {
     contents: VecDeque<Message>,
 }
@@ -49,11 +50,3 @@ impl MessageQueue {
         self.contents.front()
     }
 }
-
-impl std::default::Default for MessageQueue {
-    fn default() -> Self {
-        Self {
-            contents: VecDeque::new(),
-        }
-    }
-}
