@@ -1,12 +1,17 @@
 use std::path;
 
-use crate::config::option::{SelectOption, SortType};
+use crate::config::option::{LineNumberStyle, SelectOption, SortType};
 use crate::io::IoWorkerOptions;
 
 #[derive(Clone, Debug)]
+#[allow(clippy::enum_variant_names)]
 pub enum Command {
     BulkRename,
+
     ChangeDirectory(path::PathBuf),
+    ParentDirectory,
+    PreviousDirectory,
+
     CommandLine(String, String),
 
     CutFiles,
@@ -21,19 +26,21 @@ pub enum Command {
     CursorMoveDown(usize),
     CursorMoveHome,
     CursorMoveEnd,
-    CursorMovePageUp,
-    CursorMovePageDown,
+    CursorMovePageUp(f64),
+    CursorMovePageDown(f64),
 
     ParentCursorMoveUp(usize),
     ParentCursorMoveDown(usize),
 
+    PreviewCursorMoveUp(usize),
+    PreviewCursorMoveDown(usize),
+
     // ChildCursorMoveUp(usize),
     // ChildCursorMoveDown(usize),
     DeleteFiles,
     NewDirectory(path::PathBuf),
     OpenFile,
     OpenFileWith(Option<usize>),
-    ParentDirectory,
 
     Quit,
     QuitToCurrentDirectory,
@@ -46,6 +53,7 @@ pub enum Command {
 
     SearchGlob(String),
     SearchString(String),
+    SearchIncremental(String),
     SearchFzf,
     SearchNext,
     SearchPrev,
@@ -59,6 +67,8 @@ pub enum Command {
 
     ToggleHiddenFiles,
 
+    SwitchLineNums(LineNumberStyle),
+
     Sort(SortType),
     SortReverse,
 
