@@ -9,7 +9,21 @@ pub trait AppExecute {
         context: &mut AppContext,
         backend: &mut TuiBackend,
         keymap_t: &AppKeyMapping,
-    ) -> JoshutoResult<()>;
+    ) -> JoshutoResult;
+}
+
+pub trait NumberedExecute {
+    fn numbered_execute(
+        &self,
+        number_prefix: usize,
+        context: &mut AppContext,
+        backend: &mut TuiBackend,
+        keymap_t: &AppKeyMapping,
+    ) -> JoshutoResult;
+}
+
+pub trait InteractiveExecute {
+    fn interactive_execute(&self, context: &mut AppContext);
 }
 
 pub trait AppCommand: AppExecute + std::fmt::Display + std::fmt::Debug {
